// () 2004  
//      .

using System;

public class WAVFile
{

    public static void Create(System.IO.Stream Stream, double Frequency, double[] Data, double Amplitude)
    {
        System.IO.BinaryWriter Writer = new System.IO.BinaryWriter(Stream);

        // Set up file with RIFF chunk info.
        char[] ChunkRiff = {'R','I','F','F'};
        char[] ChunkType = {'W','A','V','E'};
        char[] ChunkFmt    = {'f','m','t',' '};
        char[] ChunkData = {'d','a','t','a'};
            
        short shPad = 1; // File padding
        int nFormatChunkLength = 0x10; // Format chunk length.
        int nLength = 0; // File length, minus first 8 bytes of RIFF description. This will be filled in later.
        short shBytesPerSample = 2; // Bytes per sample.

        // Fill in the riff info for the wave file.
        Writer.Write(ChunkRiff);
        Writer.Write(nLength);
        Writer.Write(ChunkType);

        // Fill in the format info for the wave file.
        Writer.Write(ChunkFmt);
        Writer.Write(nFormatChunkLength);
        Writer.Write(shPad);
        Writer.Write((short)1); // Channels.
        Writer.Write((int)Frequency); // Samples per second.
        Writer.Write((int)Frequency * 2); // Average bytes per second.
        Writer.Write(shBytesPerSample);
        Writer.Write((short)16); // Bits per sample.
            
        // Now fill in the data chunk.
        Writer.Write(ChunkData);
        Writer.Write((int)0);    // The sample length will be written in later.

        int SampleCount = Data.Length * 2;
        foreach (double x in Data)
        {
            double y = x / Amplitude * 32767.0;
            int z = (int)y;
            Writer.Write((short)((short)z));
        }

        Writer.Seek(4, System.IO.SeekOrigin.Begin); // Seek to the length descriptor of the RIFF file.
        Writer.Write((int)(SampleCount + 36)); // Write the file length, minus first 8 bytes of RIFF description.
        Writer.Seek(40, System.IO.SeekOrigin.Begin); // Seek to the data length descriptor of the RIFF file.
        Writer.Write(SampleCount); // Write the length of the sample data in bytes.            
        Writer.Close();  // Close the file now.
    }

}
